@@ -26,7 +26,7 @@ use Hash::Util;
 
 =head1 NAME
 
-OP::Hash - Hashtable object
+OP::Hash
 
 =head1 DESCRIPTION
 
