@@ -12,7 +12,7 @@
 
 =head1 NAME
 
-OP::Log - Circular message sink wrapper
+OP::Log
 
 =head1 DESCRIPTION
 
