@@ -14,7 +14,11 @@ package OP::Utility;
 
 =head1 NAME
 
-OP::Utility - System functions required globally by OP
+OP::Utility
+
+=head1 DESCRIPTION
+
+System functions required globally by OP
 
 =head1 SYNOPSIS
 
